@@ -907,6 +907,10 @@ class EditorApplication:
         """Basic curses configurations."""
         curses.curs_set(1)  # Show cursor
         self.stdscr.nodelay(False)  # Blocking input
+        # Enter raw mode to handle Ctrl+S, Ctrl+Q, Ctrl+C etc. directly
+        # curses.wrapper puts terminal in cbreak mode, raw() is more fundamental.
+        curses.raw()
+        self.stdscr.keypad(True) # Ensure special keys like arrows are processed
         curses.mousemask(curses.ALL_MOUSE_EVENTS | curses.REPORT_MOUSE_POSITION)
         # `start_color` and `use_default_colors` are called in ColorManager
 
@@ -928,37 +932,56 @@ class EditorApplication:
                 key = self.stdscr.getch()
             except curses.error: # Interrupted system call (e.g. window resize)
                 continue 
-            except KeyboardInterrupt: # Treat Ctrl+C as Ctrl+Q for quit
-                key = 17 # Simulate Ctrl+Q
+            except KeyboardInterrupt: # Fallback, less likely for Ctrl+C in raw mode
+                key = 17 # Simulate Ctrl+Q (DC1)
+            
+            if key == 3: # In raw mode, Ctrl+C often sends ETX (ASCII 3)
+                key = 17 # Map to our standard Ctrl+Q keycode
 
             if self.input_handler.process_key(self.stdscr, key):
                 break # Exit loop if process_key signals to quit
 
 
 def main_curses_wrapper(stdscr: 'curses._CursesWindow', filepath: Optional[str]) -> None:
-    """Wraps the main application logic for curses."""
+    """
+    The core curses application logic. This function is called BY curses.wrapper.
+    Assumes curses is initialized. The calling wrapper should handle locale.
+    """
     app = EditorApplication(stdscr, filepath)
     app.run()
 
-if __name__ == "__main__":
-    # It's good practice to set locale for curses to handle unicode correctly
+def launch_editor_cli(filepath: Optional[str]) -> None:
+    """
+    Entry point for launching the editor from an external Python script (like tinycoder).
+    Handles locale setup before invoking curses.wrapper.
+    """
+
     try:
+        # Set locale to the user's preference. Essential for curses to handle
+        # character encoding correctly, especially for input and display of non-ASCII.
         locale.setlocale(locale.LC_ALL, '')
     except locale.Error:
-        pass # Silently ignore if locale cannot be set
+        # If locale cannot be set, print a warning to stderr
+        print("Warning: Could not set system locale for the editor. Unicode characters may not display/input correctly.", file=os.sys.stderr)
+    except Exception as e:
+        # Catch any other unexpected error during locale setup
+        print(f"Warning: An unexpected error ({type(e).__name__}) occurred while setting locale for the editor: {e}", file=os.sys.stderr)
 
-    # Allow passing a filename as a command-line argument
-    initial_filepath: Optional[str] = None
+    curses.wrapper(main_curses_wrapper, filepath)
+    
+if __name__ == "__main__":
+    # This block is for running editor.py directly as a script
+    _initial_filepath: Optional[str] = None
     if len(os.sys.argv) > 1:
-        initial_filepath = os.sys.argv[1]
+        _initial_filepath = os.sys.argv[1]
     else:
         # If no file specified, could default to this source file for demo
-        initial_filepath = __file__ 
+        _initial_filepath = __file__ 
 
     try:
-        curses.wrapper(main_curses_wrapper, initial_filepath)
+        launch_editor_cli(_initial_filepath) # Use the new entry point
     except Exception as e:
         # This print is outside curses, so it should be visible
-        print("An error occurred outside the editor UI:")
+        print("An error occurred running the editor standalone:")
         print(f"{type(e).__name__}: {e}")
-        traceback.print_exc()
\ No newline at end of file
+        traceback.print_exc()
